@@ -578,11 +578,11 @@ void MainWindow::onShoot(int x, int y) {
     if ( !shotlimiter_ ) {
         Bullet* tmpbullet = new Bullet;
 
-        if ( x < 1000 &&
-             ((x > hero_->x() && hero_->getDirection()) ||
-             (x < hero_->x() && hero_->getDirection() == 0 )) ) {
-            return;
-        }
+//        if ( x < 1000 &&
+//             ((x > hero_->x() && hero_->getDirection()) ||
+//             (x < hero_->x() && hero_->getDirection() == 0 )) ) {
+//            return;
+//        }
 
         tmpbullet->direction_ = hero_->getDirection();
         qreal newy = (hero_->y()+25);
