@@ -17,12 +17,17 @@ MyGfxView::MyGfxView(QWidget *parent) :
 
 void MyGfxView::bgLottery() {
     QString bgfile;
+    static int previous = -1;
     if ( keyUDown_ ) {
         bgfile = ":/gfx/bgbonus.png";
     }
     else {
         int bgcount = 4; // Number of bg images
-        int bgnum = qrand() % bgcount;
+        int bgnum = -1;
+        do {
+           bgnum = qrand() % bgcount;
+        } while (bgnum == previous);
+        previous = bgnum;
         bgfile = ":/gfx/bg" + QString::number(bgnum) + ".png";
     }
     bgpix_.load(bgfile, "PNG");
